@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -35,8 +33,7 @@ from google.oauth2 import service_account  # type: ignore
 from google.cloud.video.transcoder_v1beta1.services.transcoder_service import pagers
 from google.cloud.video.transcoder_v1beta1.types import resources
 from google.cloud.video.transcoder_v1beta1.types import services
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import TranscoderServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import TranscoderServiceGrpcTransport
 from .transports.grpc_asyncio import TranscoderServiceGrpcAsyncIOTransport
@@ -59,7 +56,7 @@ class TranscoderServiceClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[TranscoderServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -89,7 +86,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -121,10 +119,27 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TranscoderServiceClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -133,7 +148,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            TranscoderServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -143,23 +158,24 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @property
     def transport(self) -> TranscoderServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            TranscoderServiceTransport: The transport used by the client instance.
+            TranscoderServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def job_path(project: str, location: str, job: str,) -> str:
-        """Return a fully-qualified job string."""
+        """Returns a fully-qualified job string."""
         return "projects/{project}/locations/{location}/jobs/{job}".format(
             project=project, location=location, job=job,
         )
 
     @staticmethod
     def parse_job_path(path: str) -> Dict[str, str]:
-        """Parse a job path into its component segments."""
+        """Parses a job path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/jobs/(?P<job>.+?)$",
             path,
@@ -168,14 +184,14 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @staticmethod
     def job_template_path(project: str, location: str, job_template: str,) -> str:
-        """Return a fully-qualified job_template string."""
+        """Returns a fully-qualified job_template string."""
         return "projects/{project}/locations/{location}/jobTemplates/{job_template}".format(
             project=project, location=location, job_template=job_template,
         )
 
     @staticmethod
     def parse_job_template_path(path: str) -> Dict[str, str]:
-        """Parse a job_template path into its component segments."""
+        """Parses a job_template path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/jobTemplates/(?P<job_template>.+?)$",
             path,
@@ -184,7 +200,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -197,7 +213,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -208,7 +224,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -219,7 +235,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -230,7 +246,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -244,12 +260,12 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, TranscoderServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the transcoder service client.
+        """Instantiates the transcoder service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -257,10 +273,10 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.TranscoderServiceTransport]): The
+            transport (Union[str, TranscoderServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -296,21 +312,18 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -322,12 +335,14 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -342,8 +357,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -353,7 +368,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -371,22 +386,23 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Creates a job in the specified region.
 
         Args:
-            request (:class:`~.services.CreateJobRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.CreateJobRequest):
                 The request object. Request message for
                 `TranscoderService.CreateJob`.
-            parent (:class:`str`):
+            parent (str):
                 Required. The parent location to create and process this
                 job. Format: ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            job (:class:`~.resources.Job`):
+            job (google.cloud.video.transcoder_v1beta1.types.Job):
                 Required. Parameters for creating
                 transcoding job.
+
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -394,7 +410,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Job:
+            google.cloud.video.transcoder_v1beta1.types.Job:
                 Transcoding job resource.
         """
         # Create or coerce a protobuf request object.
@@ -413,10 +429,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.CreateJobRequest):
             request = services.CreateJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if job is not None:
@@ -450,17 +464,17 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Lists jobs in the specified region.
 
         Args:
-            request (:class:`~.services.ListJobsRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.ListJobsRequest):
                 The request object. Request message for
                 `TranscoderService.ListJobs`. The parent location from
                 which to retrieve the collection of jobs.
-            parent (:class:`str`):
+            parent (str):
                 Required. Format:
                 ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -468,8 +482,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListJobsPager:
-                Response message for ``TranscoderService.ListJobs``.
+            google.cloud.video.transcoder_v1beta1.services.transcoder_service.pagers.ListJobsPager:
+                Response message for TranscoderService.ListJobs.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -491,10 +505,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.ListJobsRequest):
             request = services.ListJobsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -532,16 +544,16 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Returns the job data.
 
         Args:
-            request (:class:`~.services.GetJobRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.GetJobRequest):
                 The request object. Request message for
                 `TranscoderService.GetJob`.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the job to retrieve. Format:
                 ``projects/{project}/locations/{location}/jobs/{job}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -549,7 +561,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.Job:
+            google.cloud.video.transcoder_v1beta1.types.Job:
                 Transcoding job resource.
         """
         # Create or coerce a protobuf request object.
@@ -568,10 +580,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.GetJobRequest):
             request = services.GetJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -603,16 +613,16 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Deletes a job.
 
         Args:
-            request (:class:`~.services.DeleteJobRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.DeleteJobRequest):
                 The request object. Request message for
                 `TranscoderService.DeleteJob`.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the job to delete. Format:
                 ``projects/{project}/locations/{location}/jobs/{job}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -635,10 +645,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.DeleteJobRequest):
             request = services.DeleteJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -671,23 +679,25 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Creates a job template in the specified region.
 
         Args:
-            request (:class:`~.services.CreateJobTemplateRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.CreateJobTemplateRequest):
                 The request object. Request message for
                 `TranscoderService.CreateJobTemplate`.
-            parent (:class:`str`):
+            parent (str):
                 Required. The parent location to create this job
                 template. Format:
                 ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            job_template (:class:`~.resources.JobTemplate`):
+            job_template (google.cloud.video.transcoder_v1beta1.types.JobTemplate):
                 Required. Parameters for creating job
                 template.
+
                 This corresponds to the ``job_template`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            job_template_id (:class:`str`):
+            job_template_id (str):
                 Required. The ID to use for the job template, which will
                 become the final component of the job template's
                 resource name.
@@ -695,10 +705,10 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 This value should be 4-63 characters, and valid
                 characters must match the regular expression
                 ``[a-zA-Z][a-zA-Z0-9_-]*``.
+
                 This corresponds to the ``job_template_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -706,7 +716,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.JobTemplate:
+            google.cloud.video.transcoder_v1beta1.types.JobTemplate:
                 Transcoding job template resource.
         """
         # Create or coerce a protobuf request object.
@@ -725,10 +735,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.CreateJobTemplateRequest):
             request = services.CreateJobTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if job_template is not None:
@@ -764,17 +772,17 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Lists job templates in the specified region.
 
         Args:
-            request (:class:`~.services.ListJobTemplatesRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.ListJobTemplatesRequest):
                 The request object. Request message for
                 `TranscoderService.ListJobTemplates`.
-            parent (:class:`str`):
+            parent (str):
                 Required. The parent location from which to retrieve the
                 collection of job templates. Format:
                 ``projects/{project}/locations/{location}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -782,9 +790,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListJobTemplatesPager:
-                Response message for
-                ``TranscoderService.ListJobTemplates``.
+            google.cloud.video.transcoder_v1beta1.services.transcoder_service.pagers.ListJobTemplatesPager:
+                Response message for TranscoderService.ListJobTemplates.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -806,10 +813,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.ListJobTemplatesRequest):
             request = services.ListJobTemplatesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -847,17 +852,17 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Returns the job template data.
 
         Args:
-            request (:class:`~.services.GetJobTemplateRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.GetJobTemplateRequest):
                 The request object. Request message for
                 `TranscoderService.GetJobTemplate`.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the job template to retrieve.
                 Format:
                 ``projects/{project}/locations/{location}/jobTemplates/{job_template}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -865,7 +870,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.resources.JobTemplate:
+            google.cloud.video.transcoder_v1beta1.types.JobTemplate:
                 Transcoding job template resource.
         """
         # Create or coerce a protobuf request object.
@@ -884,10 +889,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.GetJobTemplateRequest):
             request = services.GetJobTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -919,16 +922,16 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         r"""Deletes a job template.
 
         Args:
-            request (:class:`~.services.DeleteJobTemplateRequest`):
+            request (google.cloud.video.transcoder_v1beta1.types.DeleteJobTemplateRequest):
                 The request object. Request message for
                 `TranscoderService.DeleteJobTemplate`.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the job template to delete.
                 ``projects/{project}/locations/{location}/jobTemplates/{job_template}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -951,10 +954,8 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, services.DeleteJobTemplateRequest):
             request = services.DeleteJobTemplateRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
